@@ -2,6 +2,3 @@
 # Author: Fábio Júnior
 # Email = fabiojdf@id.uff.br
 # License: LPGL
-
-def soma(a, b):
-    return a + b
\ No newline at end of file
